import java.awt.*;
import javax.swing.*;
import java.awt.image.BufferedImage;

/**
 * A Canvas for drawing on. Uses double-buffering for animated rendering.
 *
 * @author Joel Ross
 */
public class DrawingCanvas extends JPanel
{
    public static final int CANVAS_WIDTH = 500;
    public static final int CANVAS_HEIGHT = 500;    

    private BufferedImage image; //buffer
    private Graphics2D brush; //for drawing on

    /**
     * Constructor for objects of class FractalCanvas
     */
    public DrawingCanvas()
    {
        this.setPreferredSize(new Dimension(CANVAS_WIDTH, CANVAS_HEIGHT));

        //set up the image
        image = new BufferedImage(CANVAS_WIDTH, CANVAS_HEIGHT, BufferedImage.TYPE_INT_ARGB);
        brush = image.createGraphics();
        this.clearDrawing();

        //frame to contain the canvas
        JFrame frame = new JFrame("Fractal");
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setResizable(false);
        frame.add(this);
        frame.pack();
        frame.setVisible(true);
    }

    /**
     * Returns a Graphics brush used to draw on the canvas
     */
    public Graphics2D getGraphics2D()
    {
        return brush;
    }

    /**
     * Clears the drawing canvas (resets it to white)
     */
    public void clearDrawing()
    {
        brush.setColor(Color.WHITE);
        brush.fillRect(0, 0, CANVAS_WIDTH, CANVAS_HEIGHT);
        brush.setColor(Color.BLACK);
        this.repaint();
    }

    /**
     * A "pause" function for use in slowing down drawing (so that you can see the growth). This method shows the current drawing after the pause ends.
     * @param milliseconds The number of milliseconds to wait
     */
    public void pause(int milliseconds)
    {
        try{
            Thread.sleep(milliseconds);
        } 
        catch (InterruptedException e){
            // ignoring exception at the moment (since we don't have multithreading that will interrupt)
        }

        this.repaint();
    }
    
    public void paintComponent(Graphics brush)
    {
        brush.drawImage(image,0,0,null);
    }

}
